// Instructions:
//   * Connect the LPD8806 data wire to PB_0
//   * Connect the LPD8806 clock wire to PB_1
//   * In setup(): call initLEDStrip(numLEDs)
//   * In perFrame(): call showStrip() first (show the previous frame), then set all LED colors for the next frame.
//
// Code by Zach Archer 2013-12-15 :: http://zacharcher.com

#include "Energia.h"
#include "timer_callback.h"
#include "lpd8806lib.h"

const uint16_t ledCount = 8;
const uint8_t FPS = 120;  // Valid range: 0..255 plz

uint8_t frameCount = 0;  // resets every FPS frames
float colorPhase = 0.0;
const float colorAdvance = 0.005;

void perFrame(void) {
  // Blink the onboard GREEN_LED once per second, just to confirm that we're alive
  if( frameCount==0 ) ROM_GPIOPinWrite( GPIO_PORTF_BASE, GPIO_PIN_3, GPIO_PIN_3 );  // GREEN_LED high
  
  // Update the strip at the top of each frame, so the frame rate stays perfectly smooth.
  // Then render the next frame afterwards.
  showStrip();
  
  // Render stuff here
  colorPhase += colorAdvance * (60.0/FPS);
  for( uint16_t i=0; i<ledCount; i++ ) {
    setHSVfloats( i, colorPhase + (i*0.075), 1.0, 1.0, true );
  }
  
  // Turn off the onboard GREEN_LED
  ROM_GPIOPinWrite( GPIO_PORTF_BASE, GPIO_PIN_3, 0 );  // GREEN_LED low
  
  frameCount++;
  if( frameCount==FPS ) frameCount = 0;
}

void setup()
{
  //pinMode( clockPin, OUTPUT );  // clock
  //pinMode( dataPin, OUTPUT );  // data
  ROM_GPIOPinTypeGPIOOutput( GPIO_PORTB_BASE, GPIO_PIN_0 | GPIO_PIN_1 );  // faster method
  
  // Enable onload Launchpad's onboard RGB LED for output
  //pinMode( RED_LED, OUTPUT );
  //pinMode( GREEN_LED, OUTPUT );
  //pinMode( BLUE_LED, OUTPUT );
  ROM_GPIOPinTypeGPIOOutput( GPIO_PORTF_BASE, GPIO_PIN_1 | GPIO_PIN_2 | GPIO_PIN_3 );  // faster method
  
  // Prepare the LED strip
  initLEDStrip( ledCount );
  
  // Start the FPS timer. The perFrame function will be called every frame.
  initTimer( FPS, &perFrame );
}

void loop()
{
  // Do nothing. All the action handles inside perFrame.
}

