#include "Energia.h"
#include "inc/hw_ints.h"
#include "driverlib/interrupt.h"
#include "driverlib/sysctl.h"
#include "driverlib/timer.h"
#include "timer_callback.h"

void(*timerCallbackFunc)(void);

void initTimer( unsigned Hz, void(*inCallbackFunc)(void) ) {
  timerCallbackFunc = inCallbackFunc;
  
  SysCtlPeripheralEnable( SYSCTL_PERIPH_TIMER0 );
  TimerConfigure( TIMER0_BASE, TIMER_CFG_PERIODIC );
  
  unsigned long ulPeriod = (SysCtlClockGet() / Hz); // / 2; // NO, divide-by-two is wrong for a periodic timer
  TimerLoadSet( TIMER0_BASE, TIMER_A, ulPeriod - 1 );
  
  IntEnable( INT_TIMER0A );
  TimerIntEnable( TIMER0_BASE, TIMER_TIMA_TIMEOUT );
  IntMasterEnable();
  
  TimerEnable( TIMER0_BASE, TIMER_A );
}

// OS X: Need to declare this function in Energia -> show contents -> find startup_ccs.c
// See this video for details: https://www.youtube.com/watch?v=PYHs7AK_91Q
void Timer0IntHandler() {
  // Clear the timer interrupt
  TimerIntClear(TIMER0_BASE, TIMER_TIMA_TIMEOUT);
  
  // Callback function
  timerCallbackFunc();
}

